==> opensubdiv-3.6.1-2.1-x86_64_v4.pkg.tar.zst: usr/share/doc/opensubdiv/doxy_html/search/all_a.js <==
var searchData=
[
  ['length_0',['length',['../a01132.html#a9f59b34b1f25fe00023291b678246bcc',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::BufferDescriptor']]],
  ['level_2eh_1',['level.h',['../a00833.html',1,'']]],
  ['limit_2',['Limit',['../a01020.html#a0357839a7fabaa02f1d6d6a3c75e1ec2',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PrimvarRefinerReal::Limit(T const &amp;src, U &amp;dstPos) const'],['../a01020.html#a2cf4c50a1117c44ba4d11db92b067401',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PrimvarRefinerReal::Limit(T const &amp;src, U &amp;dstPos, U1 &amp;dstTan1, U2 &amp;dstTan2) const']]],
  ['limitfacevarying_3',['LimitFaceVarying',['../a01020.html#afdee0e9e9c6edd34c96892efff808a87',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PrimvarRefinerReal']]],
  ['limits_4',['Limits',['../a00908.html',1,'OpenSubdiv::OPENSUBDIV_VERSION::Bfr']]],
  ['limits_2eh_5',['limits.h',['../a00887.html',1,'']]],
  ['limitstencil_6',['LimitStencil',['../a01064.html',1,'LimitStencil'],['../a01064.html#a071ea9b75540c3d54d9bf934fc944e5a',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::LimitStencil::LimitStencil(BaseStencil const &amp;other)'],['../a01064.html#a51e1d601373aa0cd9ce70b630ce22adf',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::LimitStencil::LimitStencil(int *size, Index *indices, float *weights, float *duWeights=0, float *dvWeights=0, float *duuWeights=0, float *duvWeights=0, float *dvvWeights=0)']]],
  ['limitstencilreal_7',['LimitStencilReal',['../a01060.html',1,'LimitStencilReal&lt; REAL &gt;'],['../a01060.html#ad6ade692f92a3bf50c813a82bd63d4c7',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::LimitStencilReal::LimitStencilReal()']]],
  ['limitstencilreal_3c_20float_20_3e_8',['LimitStencilReal&lt; float &gt;',['../a01060.html',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far']]],
  ['limitstenciltable_9',['LimitStencilTable',['../a01072.html',1,'LimitStencilTable'],['../a01072.html#a45723c21481c3887e0740fe69acbac40',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::LimitStencilTable::LimitStencilTable()']]],
  ['limitstenciltablefactory_10',['LimitStencilTableFactory',['../a01092.html',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far']]],
  ['limitstenciltablefactoryreal_11',['LimitStencilTableFactoryReal',['../a01040.html',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far']]],
  ['limitstenciltablefactoryreal_3c_20float_20_3e_12',['LimitStencilTableFactoryReal&lt; float &gt;',['../a01040.html',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far']]],
  ['limitstenciltablefactoryreal_3c_20real_20_3e_13',['LimitStencilTableFactoryReal&lt; REAL &gt;',['../a01044.html#a19f9c49c05d967ad8e51bc2a696caf4b',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::StencilReal::LimitStencilTableFactoryReal&lt; REAL &gt;()'],['../a01060.html#a19f9c49c05d967ad8e51bc2a696caf4b',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::LimitStencilReal::LimitStencilTableFactoryReal&lt; REAL &gt;()'],['../a01068.html#a19f9c49c05d967ad8e51bc2a696caf4b',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::LimitStencilTableReal::LimitStencilTableFactoryReal&lt; REAL &gt;()']]],
  ['limitstenciltablereal_14',['LimitStencilTableReal',['../a01068.html',1,'LimitStencilTableReal&lt; REAL &gt;'],['../a01068.html#a8bd530eac9ff33dc0b117d5f4a0cb939',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::LimitStencilTableReal::LimitStencilTableReal()']]],
  ['limitstenciltablereal_3c_20float_20_3e_15',['LimitStencilTableReal&lt; float &gt;',['../a01068.html',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far']]],
  ['lines_16',['LINES',['../a00964.html#a1d1cfd8ffb84e947f82999c682b666a7a0b25cd15c2c168baf13ac0feb3980f40',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchDescriptor']]],
  ['localindex_17',['LocalIndex',['../a00899.html#a200172f1c19545bc01f292afa2167e2f',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::LocalIndex'],['../a00900.html#a97c1e0c5ac33f97e2b73fde56b56c363',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::LocalIndex']]],
  ['localindexarray_18',['LocalIndexArray',['../a00899.html#a26b477946e364f3510ef5028d66132f3',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::LocalIndexArray'],['../a00900.html#a1e004d5c1e30ef69719d4083afe0f4ce',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::LocalIndexArray']]],
  ['localmask_19',['LocalMask',['../a01324.html',1,'Scheme&lt; SCHEME_TYPE &gt;::LocalMask&lt; WEIGHT &gt;'],['../a01324.html#ac4b4c55fb24da95f154f4a9f517db079',1,'OpenSubdiv::OPENSUBDIV_VERSION::Sdc::Scheme::LocalMask::LocalMask()']]],
  ['localpointfacevaryingstencilprecisionmatchestype_20',['LocalPointFaceVaryingStencilPrecisionMatchesType',['../a00984.html#a38d50a271b91fe5b1a9f11904d06ce49',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::LocalPointFaceVaryingStencilPrecisionMatchesType() const'],['../a00984.html#a4814cce8e9b999c4dbb64bcf09ab73e1',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::LocalPointFaceVaryingStencilPrecisionMatchesType() const'],['../a00984.html#a4814cce8e9b999c4dbb64bcf09ab73e1',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::LocalPointFaceVaryingStencilPrecisionMatchesType() const']]],
  ['localpointstencilprecisionmatchestype_21',['LocalPointStencilPrecisionMatchesType',['../a00984.html#ae7d9c513e950df25aebfeed309666764',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::LocalPointStencilPrecisionMatchesType() const'],['../a00984.html#a24c2f632253c21d97fdba264ac2635a9',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::LocalPointStencilPrecisionMatchesType() const'],['../a00984.html#a24c2f632253c21d97fdba264ac2635a9',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::LocalPointStencilPrecisionMatchesType() const']]],
  ['localpointvaryingstencilprecisionmatchestype_22',['LocalPointVaryingStencilPrecisionMatchesType',['../a00984.html#ab181437e35cfc57ef3efdd368bb51a69',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::LocalPointVaryingStencilPrecisionMatchesType() const'],['../a00984.html#af22fd3afdc99098cc89463f530de5011',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::LocalPointVaryingStencilPrecisionMatchesType() const'],['../a00984.html#af22fd3afdc99098cc89463f530de5011',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::LocalPointVaryingStencilPrecisionMatchesType() const']]],
  ['locationarray_23',['LocationArray',['../a01084.html',1,'LimitStencilTableFactoryReal&lt; REAL &gt;::LocationArray'],['../a01084.html#a23ed026fe98bd57164dbb601791f51fc',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::LimitStencilTableFactoryReal::LocationArray::LocationArray()']]],
  ['locationarrayvec_24',['LocationArrayVec',['../a01040.html#a940880e2d35dea72f52db5bcdc9c94b7',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::LimitStencilTableFactoryReal']]],
  ['loop_25',['LOOP',['../a00964.html#a1d1cfd8ffb84e947f82999c682b666a7a61f7f1587bd5fe978d9ff3ece8d0624c',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchDescriptor']]],
  ['loopscheme_2eh_26',['loopScheme.h',['../a00863.html',1,'']]]
];

==> opensubdiv-3.7.0-1.1-x86_64_v4.pkg.tar.zst: usr/share/doc/opensubdiv/doxy_html/search/all_a.js <==
var searchData=
[
  ['length_0',['length',['../a01132.html#a9f59b34b1f25fe00023291b678246bcc',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::BufferDescriptor']]],
  ['level_2eh_1',['level.h',['../a00833.html',1,'']]],
  ['limit_2',['Limit',['../a01020.html#a0357839a7fabaa02f1d6d6a3c75e1ec2',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PrimvarRefinerReal::Limit(T const &amp;src, U &amp;dstPos) const'],['../a01020.html#a2cf4c50a1117c44ba4d11db92b067401',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PrimvarRefinerReal::Limit(T const &amp;src, U &amp;dstPos, U1 &amp;dstTan1, U2 &amp;dstTan2) const']]],
  ['limitfacevarying_3',['LimitFaceVarying',['../a01020.html#afdee0e9e9c6edd34c96892efff808a87',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PrimvarRefinerReal']]],
  ['limits_4',['Limits',['../a00908.html',1,'OpenSubdiv::OPENSUBDIV_VERSION::Bfr']]],
  ['limits_2eh_5',['limits.h',['../a00887.html',1,'']]],
  ['limitstencil_6',['LimitStencil',['../a01064.html',1,'LimitStencil'],['../a01064.html#a071ea9b75540c3d54d9bf934fc944e5a',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::LimitStencil::LimitStencil(BaseStencil const &amp;other)'],['../a01064.html#a51e1d601373aa0cd9ce70b630ce22adf',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::LimitStencil::LimitStencil(int *size, Index *indices, float *weights, float *duWeights=0, float *dvWeights=0, float *duuWeights=0, float *duvWeights=0, float *dvvWeights=0)']]],
  ['limitstencilreal_7',['LimitStencilReal',['../a01060.html',1,'LimitStencilReal&lt; REAL &gt;'],['../a01060.html#ad6ade692f92a3bf50c813a82bd63d4c7',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::LimitStencilReal::LimitStencilReal()']]],
  ['limitstencilreal_3c_20float_20_3e_8',['LimitStencilReal&lt; float &gt;',['../a01060.html',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far']]],
  ['limitstenciltable_9',['LimitStencilTable',['../a01072.html',1,'LimitStencilTable'],['../a01072.html#a45723c21481c3887e0740fe69acbac40',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::LimitStencilTable::LimitStencilTable()']]],
  ['limitstenciltablefactory_10',['LimitStencilTableFactory',['../a01092.html',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far']]],
  ['limitstenciltablefactoryreal_11',['LimitStencilTableFactoryReal',['../a01040.html',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far']]],
  ['limitstenciltablefactoryreal_3c_20float_20_3e_12',['LimitStencilTableFactoryReal&lt; float &gt;',['../a01040.html',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far']]],
  ['limitstenciltablefactoryreal_3c_20real_20_3e_13',['LimitStencilTableFactoryReal&lt; REAL &gt;',['../a01044.html#a19f9c49c05d967ad8e51bc2a696caf4b',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::StencilReal::LimitStencilTableFactoryReal&lt; REAL &gt;()'],['../a01060.html#a19f9c49c05d967ad8e51bc2a696caf4b',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::LimitStencilReal::LimitStencilTableFactoryReal&lt; REAL &gt;()'],['../a01068.html#a19f9c49c05d967ad8e51bc2a696caf4b',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::LimitStencilTableReal::LimitStencilTableFactoryReal&lt; REAL &gt;()']]],
  ['limitstenciltablereal_14',['LimitStencilTableReal',['../a01068.html',1,'LimitStencilTableReal&lt; REAL &gt;'],['../a01068.html#a8bd530eac9ff33dc0b117d5f4a0cb939',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::LimitStencilTableReal::LimitStencilTableReal()']]],
  ['limitstenciltablereal_3c_20float_20_3e_15',['LimitStencilTableReal&lt; float &gt;',['../a01068.html',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far']]],
  ['lines_16',['LINES',['../a00964.html#a1d1cfd8ffb84e947f82999c682b666a7a0b25cd15c2c168baf13ac0feb3980f40',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchDescriptor']]],
  ['localindex_17',['LocalIndex',['../a00899.html#a200172f1c19545bc01f292afa2167e2f',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::LocalIndex'],['../a00900.html#a97c1e0c5ac33f97e2b73fde56b56c363',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::LocalIndex']]],
  ['localindexarray_18',['LocalIndexArray',['../a00899.html#a26b477946e364f3510ef5028d66132f3',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::LocalIndexArray'],['../a00900.html#a1e004d5c1e30ef69719d4083afe0f4ce',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::LocalIndexArray']]],
  ['localmask_19',['LocalMask',['../a01324.html',1,'Scheme&lt; SCHEME_TYPE &gt;::LocalMask&lt; WEIGHT &gt;'],['../a01324.html#ac4b4c55fb24da95f154f4a9f517db079',1,'OpenSubdiv::OPENSUBDIV_VERSION::Sdc::Scheme::LocalMask::LocalMask()']]],
  ['localpointfacevaryingstencilprecisionmatchestype_20',['LocalPointFaceVaryingStencilPrecisionMatchesType',['../a00984.html#a38d50a271b91fe5b1a9f11904d06ce49',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::LocalPointFaceVaryingStencilPrecisionMatchesType() const'],['../a00984.html#a4814cce8e9b999c4dbb64bcf09ab73e1',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::LocalPointFaceVaryingStencilPrecisionMatchesType() const'],['../a00984.html#a4814cce8e9b999c4dbb64bcf09ab73e1',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::LocalPointFaceVaryingStencilPrecisionMatchesType() const']]],
  ['localpointstencilprecisionmatchestype_21',['LocalPointStencilPrecisionMatchesType',['../a00984.html#ae7d9c513e950df25aebfeed309666764',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::LocalPointStencilPrecisionMatchesType() const'],['../a00984.html#a24c2f632253c21d97fdba264ac2635a9',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::LocalPointStencilPrecisionMatchesType() const'],['../a00984.html#a24c2f632253c21d97fdba264ac2635a9',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::LocalPointStencilPrecisionMatchesType() const']]],
  ['localpointvaryingstencilprecisionmatchestype_22',['LocalPointVaryingStencilPrecisionMatchesType',['../a00984.html#ab181437e35cfc57ef3efdd368bb51a69',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::LocalPointVaryingStencilPrecisionMatchesType() const'],['../a00984.html#af22fd3afdc99098cc89463f530de5011',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::LocalPointVaryingStencilPrecisionMatchesType() const'],['../a00984.html#af22fd3afdc99098cc89463f530de5011',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchTable::LocalPointVaryingStencilPrecisionMatchesType() const']]],
  ['location_23',['LOCATION',['../a01240.html#a0d69e605dd5e16b2ffb7b70fd30485dd',1,'OpenSubdiv::OPENSUBDIV_VERSION::Osd::GLXFBEvaluator']]],
  ['locationarray_24',['LocationArray',['../a01084.html',1,'LimitStencilTableFactoryReal&lt; REAL &gt;::LocationArray'],['../a01084.html#a23ed026fe98bd57164dbb601791f51fc',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::LimitStencilTableFactoryReal::LocationArray::LocationArray()']]],
  ['locationarrayvec_25',['LocationArrayVec',['../a01040.html#a940880e2d35dea72f52db5bcdc9c94b7',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::LimitStencilTableFactoryReal']]],
  ['loop_26',['LOOP',['../a00964.html#a1d1cfd8ffb84e947f82999c682b666a7a61f7f1587bd5fe978d9ff3ece8d0624c',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchDescriptor']]],
  ['loopscheme_2eh_27',['loopScheme.h',['../a00863.html',1,'']]]
];
